# -*- coding: utf-8 -*-

VERSION = "3.18.0"
PACKAGE = "gedit-plugins"
PACKAGE_STRING = "gedit-plugins 3.18.0"
GETTEXT_PACKAGE = "gedit-plugins"
GP_LOCALEDIR = "/home/paolo/gnome/install/@DATADIRNAME@/locale"
